@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '2.46';
+our $VERSION = '2.47';
 
 use base qw( Log::Dispatch::Base );
 
@@ -300,7 +300,7 @@ Log::Dispatch - Dispatches messages to one or more outputs
 
 =head1 VERSION
 
-version 2.46
+version 2.47
 
 =head1 SYNOPSIS
 
@@ -710,7 +710,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Olaf Alders Olivier Mengué Ross Attrill swartz@jonathan-swartzs-macbook-4.local swartz@pobox.com Whitney Jackson
+=for stopwords Karen Etheridge Olaf Alders Olivier Mengué Rohan Carly Ross Attrill swartz@jonathan-swartzs-macbook-4.local swartz@pobox.com Whitney Jackson
 
 =over 4
 
@@ -728,6 +728,10 @@ Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
+Rohan Carly <se456@rohan.id.au>
+
+=item *
+
 Ross Attrill <ross.attrill@gmail.com>
 
 =item *
